==> dde-session-shell_5.5.69.orig.tar.xz: dde-session-shell-5.5.69/translations/dde-session-shell_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ID do rosto</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifique a ID do rosto</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ID do rosto bloqueada, usar a palavra-passe</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada, utilize a palavra-passe</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID da íris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifique a ID da íris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>ID da íris bloqueada, usar a palavra-passe</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Repor palavra-passe</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Esqueceu-se da palavra-passe?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Repor palavra-passe</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Esqueceu-se da palavra-passe?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey é necessária</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Introduza o seu PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>A palavra-passe expirará dentro de %n dia. Altere-a atempadamente</numerusform><numerusform>A palavra-passe expirará dentro de %n dias. Altere-a atempadamente</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>A palavra-passe expirou, altere-a</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Conta incorreta</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear ecrã</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>O bloqueio do ecrã falhou</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>A verificação da impressão digital expirou, insira manualmente a sua palavra-passe</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>A impressão digital não coincide</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se encerrar. Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se reiniciar. Tem a certeza que deseja reiniciar?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Ativou o modo de alta segurança no sistema, impedindo de alterar para o modo Wayland. Por favor desative o modo de alta segurança no Centro de Segurança e tente novamente.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Trocar de utilizador</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Mudar de sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Iniciar monitor do sistema</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de encerrar. Forçar o encerramento pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em Cancelar e depois feche o programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de reiniciar. Forçar o reinício pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em suspensão. Forçar a suspensão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em hibernação. Forçar a hibernação pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de terminar sessão. Forçar o término da sessão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Tem a certeza que deseja reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Tem a certeza que deseja terminar a sessão?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desligar</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.81.orig.tar.xz: dde-session-shell-5.5.81/translations/dde-session-shell_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ID do rosto</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifique a ID do rosto</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ID do rosto bloqueada, usar a palavra-passe</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Dispositivo indisponível!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada, utilize a palavra-passe</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID da íris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifique a ID da íris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>ID da íris bloqueada, usar a palavra-passe</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Repor palavra-passe</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Esqueceu-se da palavra-passe?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Repor palavra-passe</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Esqueceu-se da palavra-passe?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Falha ao verificar, %n tentativa restante</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform><numerusform>Falha ao verificar, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey é necessária</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Introduza o seu PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>A palavra-passe expirou, altere-a</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Conta incorreta</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear ecrã</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>O bloqueio do ecrã falhou</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>A verificação da impressão digital expirou, insira manualmente a sua palavra-passe</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>A impressão digital não coincide</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se encerrar. Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se reiniciar. Tem a certeza que deseja reiniciar?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Ativou o modo de alta segurança no sistema, não podendo assim mudar para o modo Wayland. Desative o modo de alta segurança no Centro de Segurança e tente novamente.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Trocar de utilizador</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Mudar de sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Iniciar monitor do sistema</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de encerrar. Forçar o encerramento pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em Cancelar e depois feche o programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de reiniciar. Forçar o reinício pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em suspensão. Forçar a suspensão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em hibernação. Forçar a hibernação pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de terminar sessão. Forçar o término da sessão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Tem a certeza que deseja reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Tem a certeza que deseja terminar a sessão?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desligar</translation>
    </message>
</context>
</TS>
